@@ -1,5 +1,4 @@
-from lxml import etree
-from io import StringIO
+from lxml import html
 
 
 def parse_html_to_tree(html_string):
@@ -11,8 +10,10 @@ def parse_html_to_tree(html_string):
     :param html_string: String of html.
     :return: ElementTree of said html.
     """
-    if 'Sorry, no records matching' in html_string or 'BEGIN: No records found error' in html_string:
+    if (
+        "Sorry, no records matching" in html_string
+        or "BEGIN: No records found error" in html_string
+    ):
         return None
-    parser = etree.HTMLParser()
-    tree = etree.parse(StringIO(html_string), parser)
+    tree = html.fromstring(html_string)
     return tree
